summaryrefslogtreecommitdiffstats
path: root/src/kernel
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel')
-rw-r--r--src/kernel/ntqnamespace.h18
-rw-r--r--src/kernel/ntqpalette.h4
-rw-r--r--src/kernel/ntqpen.h2
-rw-r--r--src/kernel/ntqpicture.h2
-rw-r--r--src/kernel/ntqpixmap.h4
-rw-r--r--src/kernel/ntqprinter.h2
-rw-r--r--src/kernel/ntqt.h24
-rw-r--r--src/kernel/qapplication.cpp2
-rw-r--r--src/kernel/qapplication_p.h2
-rw-r--r--src/kernel/qapplication_x11.cpp10
-rw-r--r--src/kernel/qdnd_x11.cpp2
-rw-r--r--src/kernel/qdrawutil.cpp2
-rw-r--r--src/kernel/qeventloop_x11.cpp2
-rw-r--r--src/kernel/qeventloop_x11_glib.cpp2
-rw-r--r--src/kernel/qinternal.cpp2
-rw-r--r--src/kernel/qpicture.cpp4
-rw-r--r--src/kernel/qpixmap.cpp2
-rw-r--r--src/kernel/qpixmap_x11.cpp4
-rw-r--r--src/kernel/qprinter_unix.cpp2
-rw-r--r--src/kernel/qpsprinter.cpp10
-rw-r--r--src/kernel/qrichtext.cpp6
-rw-r--r--src/kernel/qrichtext_p.h8
-rw-r--r--src/kernel/qscriptengine.cpp4
-rw-r--r--src/kernel/qt_kernel.pri72
-rw-r--r--src/kernel/qt_pch.h2
-rw-r--r--src/kernel/qvariant.cpp6
-rw-r--r--src/kernel/qwmatrix.cpp2
-rw-r--r--src/kernel/tqbrush.h (renamed from src/kernel/ntqbrush.h)2
-rw-r--r--src/kernel/tqcolor.cpp (renamed from src/kernel/qcolor.cpp)4
-rw-r--r--src/kernel/tqcolor.h (renamed from src/kernel/ntqcolor.h)0
-rw-r--r--src/kernel/tqcolor_p.cpp (renamed from src/kernel/qcolor_p.cpp)2
-rw-r--r--src/kernel/tqcolor_p.h (renamed from src/kernel/qcolor_p.h)0
-rw-r--r--src/kernel/tqcolor_x11.cpp (renamed from src/kernel/qcolor_x11.cpp)8
-rw-r--r--src/kernel/tqdragobject.h2
-rw-r--r--src/kernel/tqfont.cpp (renamed from src/kernel/qfont.cpp)28
-rw-r--r--src/kernel/tqfont.h (renamed from src/kernel/ntqfont.h)2
-rw-r--r--src/kernel/tqfont_x11.cpp (renamed from src/kernel/qfont_x11.cpp)20
-rw-r--r--src/kernel/tqfontdata_p.h (renamed from src/kernel/qfontdata_p.h)4
-rw-r--r--src/kernel/tqfontdatabase.cpp (renamed from src/kernel/qfontdatabase.cpp)16
-rw-r--r--src/kernel/tqfontdatabase.h (renamed from src/kernel/ntqfontdatabase.h)2
-rw-r--r--src/kernel/tqfontdatabase_x11.cpp (renamed from src/kernel/qfontdatabase_x11.cpp)8
-rw-r--r--src/kernel/tqfontengine_p.h (renamed from src/kernel/qfontengine_p.h)0
-rw-r--r--src/kernel/tqfontengine_x11.cpp (renamed from src/kernel/qfontengine_x11.cpp)14
-rw-r--r--src/kernel/tqfontinfo.h (renamed from src/kernel/ntqfontinfo.h)2
-rw-r--r--src/kernel/tqfontmetrics.h (renamed from src/kernel/ntqfontmetrics.h)2
-rw-r--r--src/kernel/tqiconset.cpp2
-rw-r--r--src/kernel/tqimage.cpp10
-rw-r--r--src/kernel/tqmovie.cpp (renamed from src/kernel/qmovie.cpp)10
-rw-r--r--src/kernel/tqmovie.h (renamed from src/kernel/ntqmovie.h)0
-rw-r--r--src/kernel/tqpaintdevice.h (renamed from src/kernel/ntqpaintdevice.h)0
-rw-r--r--src/kernel/tqpaintdevice_x11.cpp (renamed from src/kernel/qpaintdevice_x11.cpp)10
-rw-r--r--src/kernel/tqpaintdevicemetrics.cpp (renamed from src/kernel/qpaintdevicemetrics.cpp)4
-rw-r--r--src/kernel/tqpaintdevicemetrics.h (renamed from src/kernel/ntqpaintdevicemetrics.h)2
-rw-r--r--src/kernel/tqpainter.cpp (renamed from src/kernel/qpainter.cpp)14
-rw-r--r--src/kernel/tqpainter.h (renamed from src/kernel/ntqpainter.h)10
-rw-r--r--src/kernel/tqpainter_p.h (renamed from src/kernel/qpainter_p.h)2
-rw-r--r--src/kernel/tqpainter_x11.cpp (renamed from src/kernel/qpainter_x11.cpp)10
-rw-r--r--src/kernel/tqsizegrip.cpp2
-rw-r--r--src/kernel/tqstyle.cpp2
-rw-r--r--src/kernel/tqstyle.h2
-rw-r--r--src/kernel/tqstylesheet.cpp2
-rw-r--r--src/kernel/tqtextengine.cpp6
-rw-r--r--src/kernel/tqtextengine_p.h2
-rw-r--r--src/kernel/tqtextlayout.cpp4
-rw-r--r--src/kernel/tqttdeintegration_x11.cpp4
-rw-r--r--src/kernel/tqwidget.cpp4
-rw-r--r--src/kernel/tqwidget.h8
-rw-r--r--src/kernel/tqwidget_x11.cpp6
68 files changed, 217 insertions, 217 deletions
diff --git a/src/kernel/ntqnamespace.h b/src/kernel/ntqnamespace.h
index 6feb7578c..b056c8363 100644
--- a/src/kernel/ntqnamespace.h
+++ b/src/kernel/ntqnamespace.h
@@ -106,7 +106,7 @@ public:
// the following four enums can be combined to one integer which
// is passed as textflag to drawText and qt_format_text.
- // documented in qpainter.cpp
+ // documented in tqpainter.cpp
enum AlignmentFlags {
AlignAuto = 0x0000, // text alignment
AlignLeft = 0x0001,
@@ -121,7 +121,7 @@ public:
AlignCenter = AlignVCenter | AlignHCenter
};
- // documented in qpainter.cpp
+ // documented in tqpainter.cpp
enum TextFlags {
SingleLine = 0x0080, // misc. flags
DontClip = 0x0100,
@@ -299,14 +299,14 @@ public:
AvoidDither = 0x00000080
};
- // documented in qpainter.cpp
+ // documented in tqpainter.cpp
enum BGMode { // background mode
TransparentMode,
OpaqueMode
};
#ifndef TQT_NO_COMPAT
- // documented in qpainter.cpp
+ // documented in tqpainter.cpp
enum PaintUnit { // paint unit
PixelUnit,
LoMetricUnit, // OBSOLETE
@@ -746,7 +746,7 @@ public:
RightArrow
};
- // documented in qpainter.cpp
+ // documented in tqpainter.cpp
enum RasterOp { // raster op mode
CopyROP,
OrROP,
@@ -766,7 +766,7 @@ public:
NorROP, LastROP=NorROP
};
- // documented in qpainter.cpp
+ // documented in tqpainter.cpp
enum PenStyle { // pen style
NoPen,
SolidLine,
@@ -778,7 +778,7 @@ public:
MPenStyle = 0x0f
};
- // documented in qpainter.cpp
+ // documented in tqpainter.cpp
enum PenCapStyle { // line endcap style
FlatCap = 0x00,
SquareCap = 0x10,
@@ -786,7 +786,7 @@ public:
MPenCapStyle = 0x30
};
- // documented in qpainter.cpp
+ // documented in tqpainter.cpp
enum PenJoinStyle { // line join style
MiterJoin = 0x00,
BevelJoin = 0x40,
@@ -794,7 +794,7 @@ public:
MPenJoinStyle = 0xc0
};
- // documented in qpainter.cpp
+ // documented in tqpainter.cpp
enum BrushStyle { // brush style
NoBrush,
SolidPattern,
diff --git a/src/kernel/ntqpalette.h b/src/kernel/ntqpalette.h
index ba673085f..9f0ca13f0 100644
--- a/src/kernel/ntqpalette.h
+++ b/src/kernel/ntqpalette.h
@@ -43,9 +43,9 @@
#ifndef QT_H
#include "ntqwindowdefs.h"
-#include "ntqcolor.h"
+#include "tqcolor.h"
#include "ntqshared.h"
-#include "ntqbrush.h" // TQColor->TQBrush conversion
+#include "tqbrush.h" // TQColor->TQBrush conversion
#endif // QT_H
#ifndef TQT_NO_PALETTE
diff --git a/src/kernel/ntqpen.h b/src/kernel/ntqpen.h
index 226ff1cf2..3a0a0f8d0 100644
--- a/src/kernel/ntqpen.h
+++ b/src/kernel/ntqpen.h
@@ -42,7 +42,7 @@
#define TQPEN_H
#ifndef QT_H
-#include "ntqcolor.h"
+#include "tqcolor.h"
#include "ntqshared.h"
#endif // QT_H
diff --git a/src/kernel/ntqpicture.h b/src/kernel/ntqpicture.h
index 3ef2867e9..28512b61f 100644
--- a/src/kernel/ntqpicture.h
+++ b/src/kernel/ntqpicture.h
@@ -42,7 +42,7 @@
#define TQPICTURE_H
#ifndef QT_H
-#include "ntqpaintdevice.h"
+#include "tqpaintdevice.h"
#include "tqbuffer.h"
#endif // QT_H
diff --git a/src/kernel/ntqpixmap.h b/src/kernel/ntqpixmap.h
index 0e0e14c4b..70609d4a7 100644
--- a/src/kernel/ntqpixmap.h
+++ b/src/kernel/ntqpixmap.h
@@ -42,8 +42,8 @@
#define TQPIXMAP_H
#ifndef QT_H
-#include "ntqpaintdevice.h"
-#include "ntqcolor.h" // char*->TQColor conversion
+#include "tqpaintdevice.h"
+#include "tqcolor.h" // char*->TQColor conversion
#include "tqstring.h" // char*->TQString conversion
#include "ntqnamespace.h"
#endif // QT_H
diff --git a/src/kernel/ntqprinter.h b/src/kernel/ntqprinter.h
index 5ec2e179c..de561901a 100644
--- a/src/kernel/ntqprinter.h
+++ b/src/kernel/ntqprinter.h
@@ -42,7 +42,7 @@
#define TQPRINTER_H
#ifndef QT_H
-#include "ntqpaintdevice.h"
+#include "tqpaintdevice.h"
#include "tqstring.h"
#include "tqstringlist.h"
#endif // QT_H
diff --git a/src/kernel/ntqt.h b/src/kernel/ntqt.h
index 5c9058a14..ae3c2820d 100644
--- a/src/kernel/ntqt.h
+++ b/src/kernel/ntqt.h
@@ -31,13 +31,13 @@
#include "ntqkeysequence.h"
#include "ntqwindowdefs.h"
#include "ntqgdict.h"
-#include "ntqfont.h"
+#include "tqfont.h"
#include "tqdatastream.h"
#include "tqpair.h"
#include "ntqpoint.h"
#include <stdio.h>
#include "tqtextstream.h"
-#include "ntqfontinfo.h"
+#include "tqfontinfo.h"
#include "tqsizepolicy.h"
#include "ntqtl.h"
#include "tqsize.h"
@@ -51,17 +51,17 @@
#include "tqdatetime.h"
#include "tqmime.h"
#include "tqasciidict.h"
-#include "ntqpaintdevice.h"
-#include "ntqfontmetrics.h"
+#include "tqpaintdevice.h"
+#include "tqfontmetrics.h"
#include "tqdict.h"
#include "ntqevent.h"
#include "tqhostaddress.h"
#include "tqstringlist.h"
-#include "ntqcolor.h"
+#include "tqcolor.h"
#include <tqdom.h>
#include "tqobject.h"
#include <ntqdrawutil.h>
-#include "ntqbrush.h"
+#include "tqbrush.h"
#include "ntqpalette.h"
#include "tqwidget.h"
#include "tqjpunicode.h"
@@ -134,7 +134,7 @@
#include "ntqheader.h"
#include <ntqmotifplusstyle.h>
#include <ntqcdestyle.h>
-#include <ntqmovie.h>
+#include <tqmovie.h>
#include "tqptrvector.h"
#include "tqmutex.h"
#include <tqnetwork.h>
@@ -144,8 +144,8 @@
#include "tqsqlfield.h"
#include <tqobjectdict.h>
#include <tqobjectlist.h>
-#include <ntqcolordialog.h>
-#include <ntqpaintdevicemetrics.h>
+#include <tqcolordialog.h>
+#include <tqpaintdevicemetrics.h>
#include "ntqpointarray.h"
#include "tqmenudata.h"
#include <ntqlistview.h>
@@ -184,7 +184,7 @@
#include <tqsessionmanager.h>
#include <tqsettings.h>
#include <ntqsgistyle.h>
-#include <ntqfontdialog.h>
+#include <tqfontdialog.h>
#include "tqtimer.h"
#include <tqsignalmapper.h>
#include <tqsignalslotimp.h>
@@ -238,7 +238,7 @@
#include <tqtextview.h>
#include "tqwaitcondition.h"
#include <ntqasyncio.h>
-#include <ntqfontdatabase.h>
+#include <tqfontdatabase.h>
#include <tqmainwindow.h>
#include <tqtoolbox.h>
#include <tqtooltip.h>
@@ -267,7 +267,7 @@
#include <ntqcheckbox.h>
#include <ntqcompactstyle.h>
#include <ntqwizard.h>
-#include <ntqpainter.h>
+#include <tqpainter.h>
#include <tqworkspace.h>
#include <tqlocalfs.h>
#include <tqxml.h>
diff --git a/src/kernel/qapplication.cpp b/src/kernel/qapplication.cpp
index 8f456790c..d37efef76 100644
--- a/src/kernel/qapplication.cpp
+++ b/src/kernel/qapplication.cpp
@@ -63,7 +63,7 @@
#ifdef TQ_WS_WIN
#include "qinputcontext_p.h"
#endif
-#include "qfontdata_p.h"
+#include "tqfontdata_p.h"
#if defined(TQT_THREAD_SUPPORT)
# include "tqmutex.h"
diff --git a/src/kernel/qapplication_p.h b/src/kernel/qapplication_p.h
index 6cb61e4ce..08911eae7 100644
--- a/src/kernel/qapplication_p.h
+++ b/src/kernel/qapplication_p.h
@@ -47,7 +47,7 @@
// -------------
//
// This file is not part of the TQt API. It exists for the convenience
-// of qapplication_*.cpp, tqwidget*.cpp, qcolor_x11.cpp, tqfiledialog.cpp
+// of qapplication_*.cpp, tqwidget*.cpp, tqcolor_x11.cpp, tqfiledialog.cpp
// and many other. This header file may change from version to version
// without notice, or even be removed.
//
diff --git a/src/kernel/qapplication_x11.cpp b/src/kernel/qapplication_x11.cpp
index 444271514..3c6e43185 100644
--- a/src/kernel/qapplication_x11.cpp
+++ b/src/kernel/qapplication_x11.cpp
@@ -63,7 +63,7 @@
#include "ntqapplication.h"
#include "qapplication_p.h"
-#include "qcolor_p.h"
+#include "tqcolor_p.h"
#include "ntqcursor.h"
#include "tqwidget.h"
#include "tqwidget_p.h"
@@ -71,7 +71,7 @@
#include "tqwidgetlist.h"
#include "tqwidgetintdict.h"
#include "tqbitarray.h"
-#include "ntqpainter.h"
+#include "tqpainter.h"
#include "ntqpixmapcache.h"
#include "tqdatetime.h"
#include "tqtextcodec.h"
@@ -441,7 +441,7 @@ extern bool qt_check_selection_sentinel(); //def in tqclipboard_x11.cpp
static void qt_save_rootinfo();
bool tqt_try_modal( TQWidget *, XEvent * );
-int qt_ncols_option = 216; // used in qcolor_x11.cpp
+int qt_ncols_option = 216; // used in tqcolor_x11.cpp
int qt_visual_option = -1;
bool qt_cmap_option = FALSE;
TQWidget *qt_button_down = 0; // widget got last button-down
@@ -1648,7 +1648,7 @@ static KeySym qt_x11_keycode_to_keysym(Display *dpy, KeyCode kc) {
#include <X11/keysymdef.h>
// ### This should be static but it isn't because of the friend declaration
-// ### in ntqpaintdevice.h which then should have a static too but can't have
+// ### in tqpaintdevice.h which then should have a static too but can't have
// ### it because "storage class specifiers invalid in friend function
// ### declarations" :-) Ideas anyone?
void tqt_init_internal( int *argcptr, char **argv,
@@ -2133,7 +2133,7 @@ void tqt_init_internal( int *argcptr, char **argv,
#endif
#if !defined(TQT_NO_XFTFREETYPE)
- // defined in qfont_x11.cpp
+ // defined in tqfont_x11.cpp
extern bool tqt_has_xft;
#ifndef QT_XFT2
if (!tqt_use_xrender)
diff --git a/src/kernel/qdnd_x11.cpp b/src/kernel/qdnd_x11.cpp
index 0a51b9f2e..accf14209 100644
--- a/src/kernel/qdnd_x11.cpp
+++ b/src/kernel/qdnd_x11.cpp
@@ -53,7 +53,7 @@
#include "tqobjectlist.h"
#include "ntqcursor.h"
#include "tqbitmap.h"
-#include "ntqpainter.h"
+#include "tqpainter.h"
#include "qt_x11_p.h"
diff --git a/src/kernel/qdrawutil.cpp b/src/kernel/qdrawutil.cpp
index c98ef3dc4..7e571418f 100644
--- a/src/kernel/qdrawutil.cpp
+++ b/src/kernel/qdrawutil.cpp
@@ -43,7 +43,7 @@
#include "tqbitmap.h"
#include "ntqpixmapcache.h"
#include "ntqapplication.h"
-#include "ntqpainter.h"
+#include "tqpainter.h"
/*!
\relates TQPainter
diff --git a/src/kernel/qeventloop_x11.cpp b/src/kernel/qeventloop_x11.cpp
index bb6f343c2..db0bb4e71 100644
--- a/src/kernel/qeventloop_x11.cpp
+++ b/src/kernel/qeventloop_x11.cpp
@@ -40,7 +40,7 @@
#include "ntqeventloop.h"
#include "ntqapplication.h"
#include "tqbitarray.h"
-#include "qcolor_p.h"
+#include "tqcolor_p.h"
#include "qt_x11_p.h"
#if defined(TQT_THREAD_SUPPORT)
diff --git a/src/kernel/qeventloop_x11_glib.cpp b/src/kernel/qeventloop_x11_glib.cpp
index e000b0ef4..ff64cb93c 100644
--- a/src/kernel/qeventloop_x11_glib.cpp
+++ b/src/kernel/qeventloop_x11_glib.cpp
@@ -43,7 +43,7 @@
#include "ntqeventloop.h"
#include "ntqapplication.h"
#include "tqbitarray.h"
-#include "qcolor_p.h"
+#include "tqcolor_p.h"
#include "qt_x11_p.h"
#if defined(TQT_THREAD_SUPPORT)
diff --git a/src/kernel/qinternal.cpp b/src/kernel/qinternal.cpp
index 389c7236c..a714333d9 100644
--- a/src/kernel/qinternal.cpp
+++ b/src/kernel/qinternal.cpp
@@ -41,7 +41,7 @@
#include "private/qinternal_p.h"
#include "tqwidget.h"
#include "ntqpixmap.h"
-#include "ntqpainter.h"
+#include "tqpainter.h"
#include "ntqcleanuphandler.h"
// Modern systems (year 2011) have very large screens in excess of 1000 pixels wide
diff --git a/src/kernel/qpicture.cpp b/src/kernel/qpicture.cpp
index 45e706cb1..35dd8439a 100644
--- a/src/kernel/qpicture.cpp
+++ b/src/kernel/qpicture.cpp
@@ -42,12 +42,12 @@
#ifndef TQT_NO_PICTURE
-#include "ntqpainter.h"
+#include "tqpainter.h"
#include "ntqpixmap.h"
#include "tqimage.h"
#include "tqfile.h"
#include "tqdatastream.h"
-#include "ntqpaintdevicemetrics.h"
+#include "tqpaintdevicemetrics.h"
#ifndef TQT_NO_SVG
#include "private/qsvgdevice_p.h"
diff --git a/src/kernel/qpixmap.cpp b/src/kernel/qpixmap.cpp
index c39a86e67..148b06da6 100644
--- a/src/kernel/qpixmap.cpp
+++ b/src/kernel/qpixmap.cpp
@@ -43,7 +43,7 @@
#include "tqbitmap.h"
#include "tqimage.h"
#include "tqwidget.h"
-#include "ntqpainter.h"
+#include "tqpainter.h"
#include "tqdatastream.h"
#include "tqbuffer.h"
#include "tqobjectlist.h"
diff --git a/src/kernel/qpixmap_x11.cpp b/src/kernel/qpixmap_x11.cpp
index 1ddb18e02..1b5be8410 100644
--- a/src/kernel/qpixmap_x11.cpp
+++ b/src/kernel/qpixmap_x11.cpp
@@ -68,7 +68,7 @@
#endif
#include "tqbitmap.h"
-#include "ntqpaintdevicemetrics.h"
+#include "tqpaintdevicemetrics.h"
#include "tqimage.h"
#include "ntqwmatrix.h"
#include "ntqapplication.h"
@@ -372,7 +372,7 @@ static void build_scale_table( uint **table, uint nBits )
static int defaultScreen = -1;
extern bool tqt_use_xrender; // defined in qapplication_x11.cpp
-extern bool tqt_has_xft; // defined in qfont_x11.cpp
+extern bool tqt_has_xft; // defined in tqfont_x11.cpp
#ifndef TQT_NO_XFTFREETYPE
#ifndef QT_XFT2
diff --git a/src/kernel/qprinter_unix.cpp b/src/kernel/qprinter_unix.cpp
index c5d613827..0c7cdfa6b 100644
--- a/src/kernel/qprinter_unix.cpp
+++ b/src/kernel/qprinter_unix.cpp
@@ -51,7 +51,7 @@ static inline int qt_open(const char *pathname, int flags, mode_t mode)
#ifndef TQT_NO_PRINTER
-#include "ntqpaintdevicemetrics.h"
+#include "tqpaintdevicemetrics.h"
#include "qpsprinter_p.h"
#include "ntqprintdialog.h"
#include "ntqapplication.h"
diff --git a/src/kernel/qpsprinter.cpp b/src/kernel/qpsprinter.cpp
index 8bd04b845..3d18d6008 100644
--- a/src/kernel/qpsprinter.cpp
+++ b/src/kernel/qpsprinter.cpp
@@ -56,9 +56,9 @@
#undef Q_PRINTER_USE_TYPE42
-#include "ntqpainter.h"
+#include "tqpainter.h"
#include "ntqapplication.h"
-#include "ntqpaintdevicemetrics.h"
+#include "tqpaintdevicemetrics.h"
#include "tqimage.h"
#include "tqdatetime.h"
#include "tqstring.h"
@@ -70,7 +70,7 @@
#include "tqtextcodec.h"
#include "tqsettings.h"
#include "tqmap.h"
-#include "ntqfontdatabase.h"
+#include "tqfontdatabase.h"
#include "tqregexp.h"
#include "tqbitmap.h"
#include <private/qunicodetables_p.h>
@@ -96,8 +96,8 @@
#endif
#if defined( TQ_WS_X11 )
-#include "qfontdata_p.h"
-#include "qfontengine_p.h"
+#include "tqfontdata_p.h"
+#include "tqfontengine_p.h"
#include "tqtextlayout_p.h"
#include "tqtextengine_p.h"
extern bool tqt_has_xft;
diff --git a/src/kernel/qrichtext.cpp b/src/kernel/qrichtext.cpp
index eb31aa554..4da7dc3e6 100644
--- a/src/kernel/qrichtext.cpp
+++ b/src/kernel/qrichtext.cpp
@@ -44,7 +44,7 @@
#include "tqstringlist.h"
-#include "ntqfont.h"
+#include "tqfont.h"
#include "tqtextstream.h"
#include "tqfile.h"
#include "ntqapplication.h"
@@ -54,8 +54,8 @@
#include "tqmime.h"
#include "tqimage.h"
#include "tqdragobject.h"
-#include "ntqpaintdevicemetrics.h"
-#include "ntqpainter.h"
+#include "tqpaintdevicemetrics.h"
+#include "tqpainter.h"
#include "ntqdrawutil.h"
#include "ntqcursor.h"
#include "tqptrstack.h"
diff --git a/src/kernel/qrichtext_p.h b/src/kernel/qrichtext_p.h
index e9422ec14..c9e40ef84 100644
--- a/src/kernel/qrichtext_p.h
+++ b/src/kernel/qrichtext_p.h
@@ -57,12 +57,12 @@
#include "tqstring.h"
#include "tqptrlist.h"
#include "ntqrect.h"
-#include "ntqfontmetrics.h"
+#include "tqfontmetrics.h"
#include "tqintdict.h"
#include "tqmap.h"
#include "tqstringlist.h"
-#include "ntqfont.h"
-#include "ntqcolor.h"
+#include "tqfont.h"
+#include "tqcolor.h"
#include "tqsize.h"
#include "tqvaluelist.h"
#include "tqvaluestack.h"
@@ -71,7 +71,7 @@
#include "ntqpixmap.h"
#include "tqstylesheet.h"
#include "tqptrvector.h"
-#include "ntqpainter.h"
+#include "tqpainter.h"
#include "ntqlayout.h"
#include "tqobject.h"
#include "ntqapplication.h"
diff --git a/src/kernel/qscriptengine.cpp b/src/kernel/qscriptengine.cpp
index 0dd19f3c3..b84aab65d 100644
--- a/src/kernel/qscriptengine.cpp
+++ b/src/kernel/qscriptengine.cpp
@@ -38,10 +38,10 @@
#include "tqstring.h"
#include "ntqrect.h"
-#include "ntqfont.h"
+#include "tqfont.h"
#include <private/qunicodetables_p.h>
#include "tqtextengine_p.h"
-#include "qfontengine_p.h"
+#include "tqfontengine_p.h"
#include <stdlib.h>
#undef None
diff --git a/src/kernel/qt_kernel.pri b/src/kernel/qt_kernel.pri
index 5cbddd2db..946fdbd96 100644
--- a/src/kernel/qt_kernel.pri
+++ b/src/kernel/qt_kernel.pri
@@ -10,10 +10,10 @@ kernel {
$$KERNEL_H/ntqasyncimageio.h \
$$KERNEL_H/ntqasyncio.h \
$$KERNEL_H/tqbitmap.h \
- $$KERNEL_H/ntqbrush.h \
+ $$KERNEL_H/tqbrush.h \
$$KERNEL_H/tqclipboard.h \
- $$KERNEL_H/ntqcolor.h \
- $$KERNEL_P/qcolor_p.h \
+ $$KERNEL_H/tqcolor.h \
+ $$KERNEL_P/tqcolor_p.h \
$$KERNEL_H/ntqconnection.h \
$$KERNEL_H/ntqcursor.h \
$$KERNEL_H/ntqdesktopwidget.h \
@@ -25,10 +25,10 @@ kernel {
$$KERNEL_P/qeventloop_p.h \
$$KERNEL_P/qeventloop_glib_p.h \
$$KERNEL_H/ntqfocusdata.h \
- $$KERNEL_H/ntqfont.h \
- $$KERNEL_P/qfontdata_p.h \
- $$KERNEL_H/ntqfontinfo.h \
- $$KERNEL_H/ntqfontmetrics.h \
+ $$KERNEL_H/tqfont.h \
+ $$KERNEL_P/tqfontdata_p.h \
+ $$KERNEL_H/tqfontinfo.h \
+ $$KERNEL_H/tqfontmetrics.h \
$$KERNEL_H/ntqguardedptr.h \
$$KERNEL_H/ntqgif.h \
$$KERNEL_H/tqiconset.h \
@@ -42,7 +42,7 @@ kernel {
$$KERNEL_H/ntqtranslator.h \
$$KERNEL_H/ntqmetaobject.h \
$$KERNEL_H/tqmime.h \
- $$KERNEL_H/ntqmovie.h \
+ $$KERNEL_H/tqmovie.h \
$$KERNEL_H/ntqnamespace.h \
$$KERNEL_H/tqnetworkprotocol.h \
$$KERNEL_H/tqobject.h \
@@ -50,11 +50,11 @@ kernel {
$$KERNEL_H/tqobjectdefs.h \
$$KERNEL_H/tqobjectdict.h \
$$KERNEL_H/tqobjectlist.h \
- $$KERNEL_H/ntqpaintdevice.h \
- $$KERNEL_H/ntqpainter.h \
- $$KERNEL_P/qpainter_p.h \
+ $$KERNEL_H/tqpaintdevice.h \
+ $$KERNEL_H/tqpainter.h \
+ $$KERNEL_P/tqpainter_p.h \
$$KERNEL_H/ntqpalette.h \
- $$KERNEL_H/ntqpaintdevicemetrics.h \
+ $$KERNEL_H/tqpaintdevicemetrics.h \
$$KERNEL_H/ntqpen.h \
$$KERNEL_H/ntqpicture.h \
$$KERNEL_H/ntqpixmap.h \
@@ -95,7 +95,7 @@ kernel {
$$KERNEL_H/ntqsimplerichtext.h \
$$KERNEL_CPP/qscriptengine_p.h \
$$KERNEL_CPP/tqtextengine_p.h \
- $$KERNEL_CPP/qfontengine_p.h \
+ $$KERNEL_CPP/tqfontengine_p.h \
$$KERNEL_CPP/tqtextlayout_p.h
inputmethod {
@@ -112,45 +112,45 @@ kernel {
win32:SOURCES += $$KERNEL_CPP/qapplication_win.cpp \
$$KERNEL_CPP/tqclipboard_win.cpp \
- $$KERNEL_CPP/qcolor_win.cpp \
+ $$KERNEL_CPP/tqcolor_win.cpp \
$$KERNEL_CPP/qcursor_win.cpp \
$$KERNEL_CPP/qdesktopwidget_win.cpp \
$$KERNEL_CPP/qdnd_win.cpp \
$$KERNEL_CPP/qeventloop_win.cpp \
- $$KERNEL_CPP/qfont_win.cpp \
+ $$KERNEL_CPP/tqfont_win.cpp \
$$KERNEL_CPP/qinputcontext_win.cpp \
$$KERNEL_CPP/tqmime_win.cpp \
$$KERNEL_CPP/qpixmap_win.cpp \
$$KERNEL_CPP/qprinter_win.cpp \
$$KERNEL_CPP/tqprocess_win.cpp \
- $$KERNEL_CPP/qpaintdevice_win.cpp \
- $$KERNEL_CPP/qpainter_win.cpp \
+ $$KERNEL_CPP/tqpaintdevice_win.cpp \
+ $$KERNEL_CPP/tqpainter_win.cpp \
$$KERNEL_CPP/qregion_win.cpp \
$$KERNEL_CPP/qsound_win.cpp \
$$KERNEL_CPP/tqthread_win.cpp \
$$KERNEL_CPP/tqwidget_win.cpp \
$$KERNEL_CPP/qole_win.c \
- $$KERNEL_CPP/qfontengine_win.cpp
+ $$KERNEL_CPP/tqfontengine_win.cpp
unix:x11 {
SOURCES += $$KERNEL_CPP/qapplication_x11.cpp \
$$KERNEL_CPP/tqclipboard_x11.cpp \
- $$KERNEL_CPP/qcolor_x11.cpp \
+ $$KERNEL_CPP/tqcolor_x11.cpp \
$$KERNEL_CPP/qcursor_x11.cpp \
$$KERNEL_CPP/qdnd_x11.cpp \
$$KERNEL_CPP/qdesktopwidget_x11.cpp \
- $$KERNEL_CPP/qfont_x11.cpp \
+ $$KERNEL_CPP/tqfont_x11.cpp \
$$KERNEL_CPP/qinputcontext.cpp \
$$KERNEL_CPP/qinputcontext_x11.cpp \
$$KERNEL_CPP/qmotifdnd_x11.cpp \
$$KERNEL_CPP/qpixmap_x11.cpp \
- $$KERNEL_CPP/qpaintdevice_x11.cpp \
- $$KERNEL_CPP/qpainter_x11.cpp \
+ $$KERNEL_CPP/tqpaintdevice_x11.cpp \
+ $$KERNEL_CPP/tqpainter_x11.cpp \
$$KERNEL_CPP/qregion_x11.cpp \
$$KERNEL_CPP/qsound_x11.cpp \
$$KERNEL_CPP/tqwidget_x11.cpp \
$$KERNEL_CPP/tqwidgetcreate_x11.cpp \
- $$KERNEL_CPP/qfontengine_x11.cpp
+ $$KERNEL_CPP/tqfontengine_x11.cpp
glibmainloop {
SOURCES += $$KERNEL_CPP/qeventloop_x11_glib.cpp
} else {
@@ -165,20 +165,20 @@ kernel {
!embedded:!x11:mac {
SOURCES += $$KERNEL_CPP/qapplication_mac.cpp \
$$KERNEL_CPP/tqclipboard_mac.cpp \
- $$KERNEL_CPP/qcolor_mac.cpp \
+ $$KERNEL_CPP/tqcolor_mac.cpp \
$$KERNEL_CPP/qcursor_mac.cpp \
$$KERNEL_CPP/tqmime_mac.cpp \
$$KERNEL_CPP/qdnd_mac.cpp \
$$KERNEL_CPP/qdesktopwidget_mac.cpp \
$$KERNEL_CPP/qpixmap_mac.cpp \
$$KERNEL_CPP/qprinter_mac.cpp \
- $$KERNEL_CPP/qpaintdevice_mac.cpp \
- $$KERNEL_CPP/qpainter_mac.cpp \
+ $$KERNEL_CPP/tqpaintdevice_mac.cpp \
+ $$KERNEL_CPP/tqpainter_mac.cpp \
$$KERNEL_CPP/qregion_mac.cpp \
$$KERNEL_CPP/tqwidget_mac.cpp \
$$KERNEL_CPP/qeventloop_mac.cpp \
- $$KERNEL_CPP/qfont_mac.cpp \
- $$KERNEL_CPP/qfontengine_mac.cpp
+ $$KERNEL_CPP/tqfont_mac.cpp \
+ $$KERNEL_CPP/tqfontengine_mac.cpp
DEFINES += QMAC_ONE_PIXEL_LOCK
} else:unix {
SOURCES += $$KERNEL_CPP/qprinter_unix.cpp \
@@ -201,8 +201,8 @@ kernel {
$$KERNEL_CPP/qasyncio.cpp \
$$KERNEL_CPP/tqbitmap.cpp \
$$KERNEL_CPP/tqclipboard.cpp \
- $$KERNEL_CPP/qcolor.cpp \
- $$KERNEL_CPP/qcolor_p.cpp \
+ $$KERNEL_CPP/tqcolor.cpp \
+ $$KERNEL_CPP/tqcolor_p.cpp \
$$KERNEL_CPP/qconnection.cpp \
$$KERNEL_CPP/qcursor.cpp \
$$KERNEL_CPP/tqdragobject.cpp \
@@ -211,8 +211,8 @@ kernel {
$$KERNEL_CPP/qevent.cpp \
$$KERNEL_CPP/qeventloop.cpp \
$$KERNEL_CPP/qfocusdata.cpp \
- $$KERNEL_CPP/qfont.cpp \
- $$KERNEL_CPP/qfontdatabase.cpp \
+ $$KERNEL_CPP/tqfont.cpp \
+ $$KERNEL_CPP/tqfontdatabase.cpp \
$$KERNEL_CPP/qguardedptr.cpp \
$$KERNEL_CPP/tqiconset.cpp \
$$KERNEL_CPP/tqimage.cpp \
@@ -223,13 +223,13 @@ kernel {
$$KERNEL_CPP/qtranslator.cpp \
$$KERNEL_CPP/qmetaobject.cpp \
$$KERNEL_CPP/tqmime.cpp \
- $$KERNEL_CPP/qmovie.cpp \
+ $$KERNEL_CPP/tqmovie.cpp \
$$KERNEL_CPP/tqnetworkprotocol.cpp \
$$KERNEL_CPP/tqobject.cpp \
$$KERNEL_CPP/tqobjectcleanuphandler.cpp \
- $$KERNEL_CPP/qpainter.cpp \
+ $$KERNEL_CPP/tqpainter.cpp \
$$KERNEL_CPP/qpalette.cpp \
- $$KERNEL_CPP/qpaintdevicemetrics.cpp \
+ $$KERNEL_CPP/tqpaintdevicemetrics.cpp \
$$KERNEL_CPP/qpicture.cpp \
$$KERNEL_CPP/qpixmap.cpp \
$$KERNEL_CPP/qpixmapcache.cpp \
@@ -267,7 +267,7 @@ kernel {
$$KERNEL_CPP/tqtextengine.cpp
unix:HEADERS += $$KERNEL_P/qpsprinter_p.h \
- $$KERNEL_H/ntqfontdatabase.h
+ $$KERNEL_H/tqfontdatabase.h
accessibility {
HEADERS += $$KERNEL_H/ntqaccessible.h
diff --git a/src/kernel/qt_pch.h b/src/kernel/qt_pch.h
index 8222ec592..bfd957097 100644
--- a/src/kernel/qt_pch.h
+++ b/src/kernel/qt_pch.h
@@ -31,7 +31,7 @@
#include <tqimage.h>
#include <ntqmetaobject.h> // All moc genereated code has this include
#include <tqobject.h>
-#include <ntqpainter.h>
+#include <tqpainter.h>
#include <ntqpixmap.h>
#include <qplatformdefs.h>
#include <tqptrlist.h>
diff --git a/src/kernel/qvariant.cpp b/src/kernel/qvariant.cpp
index 19e8f85ac..3f8944ab7 100644
--- a/src/kernel/qvariant.cpp
+++ b/src/kernel/qvariant.cpp
@@ -44,14 +44,14 @@
#ifndef TQT_NO_VARIANT
#include "tqstring.h"
#include "tqcstring.h"
-#include "ntqfont.h"
+#include "tqfont.h"
#include "ntqpixmap.h"
#include "tqimage.h"
-#include "ntqbrush.h"
+#include "tqbrush.h"
#include "ntqpoint.h"
#include "ntqrect.h"
#include "tqsize.h"
-#include "ntqcolor.h"
+#include "tqcolor.h"
#include "ntqpalette.h"
#include "tqiconset.h"
#include "tqdatastream.h"
diff --git a/src/kernel/qwmatrix.cpp b/src/kernel/qwmatrix.cpp
index 6c881b208..78dc80c0d 100644
--- a/src/kernel/qwmatrix.cpp
+++ b/src/kernel/qwmatrix.cpp
@@ -42,7 +42,7 @@
#include "tqdatastream.h"
#include "ntqregion.h"
#if defined(TQ_WS_X11)
-double qsincos( double, bool calcCos ); // defined in qpainter_x11.cpp
+double qsincos( double, bool calcCos ); // defined in tqpainter_x11.cpp
#else
#include <math.h>
#endif
diff --git a/src/kernel/ntqbrush.h b/src/kernel/tqbrush.h
index 93b375a68..6ec4424e6 100644
--- a/src/kernel/ntqbrush.h
+++ b/src/kernel/tqbrush.h
@@ -42,7 +42,7 @@
#define TQBRUSH_H
#ifndef QT_H
-#include "ntqcolor.h"
+#include "tqcolor.h"
#include "ntqshared.h"
#endif // QT_H
diff --git a/src/kernel/qcolor.cpp b/src/kernel/tqcolor.cpp
index 8d7a72935..59f726694 100644
--- a/src/kernel/qcolor.cpp
+++ b/src/kernel/tqcolor.cpp
@@ -38,7 +38,7 @@
**
**********************************************************************/
-#include "ntqcolor.h"
+#include "tqcolor.h"
#include "ntqnamespace.h"
#include "tqdatastream.h"
@@ -46,7 +46,7 @@
/*!
- \class TQColor ntqcolor.h
+ \class TQColor tqcolor.h
\brief The TQColor class provides colors based on RGB or HSV values.
\ingroup images
diff --git a/src/kernel/ntqcolor.h b/src/kernel/tqcolor.h
index 0fca55097..0fca55097 100644
--- a/src/kernel/ntqcolor.h
+++ b/src/kernel/tqcolor.h
diff --git a/src/kernel/qcolor_p.cpp b/src/kernel/tqcolor_p.cpp
index e7e33c9cb..0a91f5c90 100644
--- a/src/kernel/qcolor_p.cpp
+++ b/src/kernel/tqcolor_p.cpp
@@ -45,7 +45,7 @@
#include "qplatformdefs.h"
#endif
-#include "ntqcolor.h"
+#include "tqcolor.h"
#ifndef TQT_NO_COLORNAMES
diff --git a/src/kernel/qcolor_p.h b/src/kernel/tqcolor_p.h
index d85cbf362..d85cbf362 100644
--- a/src/kernel/qcolor_p.h
+++ b/src/kernel/tqcolor_p.h
diff --git a/src/kernel/qcolor_x11.cpp b/src/kernel/tqcolor_x11.cpp
index b223222a9..f5cfc024a 100644
--- a/src/kernel/qcolor_x11.cpp
+++ b/src/kernel/tqcolor_x11.cpp
@@ -38,10 +38,10 @@
**
**********************************************************************/
-#include "ntqcolor.h"
-#include "qcolor_p.h"
+#include "tqcolor.h"
+#include "tqcolor_p.h"
#include "string.h"
-#include "ntqpaintdevice.h"
+#include "tqpaintdevice.h"
#include "ntqapplication.h"
#include "qapplication_p.h"
#include "qt_x11_p.h"
@@ -629,7 +629,7 @@ uint TQColor::pixel( int screen ) const
void TQColor::setSystemNamedColor( const TQString& name )
{
// setSystemNamedColor should look up rgb values from the built in
- // color tables first (see qcolor_p.cpp), and failing that, use
+ // color tables first (see tqcolor_p.cpp), and failing that, use
// the window system's interface for translating names to rgb values...
// we do this so that things like uic can load an XPM file with named colors
// and convert it to a png without having to use window system functions...
diff --git a/src/kernel/tqdragobject.h b/src/kernel/tqdragobject.h
index af4a8a995..568e0cbd8 100644
--- a/src/kernel/tqdragobject.h
+++ b/src/kernel/tqdragobject.h
@@ -49,7 +49,7 @@ class TQImageDragData;
#include "tqobject.h"
#include "tqimage.h"
#include "tqstrlist.h"
-#include "ntqcolor.h"
+#include "tqcolor.h"
#endif // QT_H
#ifndef TQT_NO_MIME
diff --git a/src/kernel/qfont.cpp b/src/kernel/tqfont.cpp
index 8910d7a11..1549b1836 100644
--- a/src/kernel/qfont.cpp
+++ b/src/kernel/tqfont.cpp
@@ -40,11 +40,11 @@
#define QT_FATAL_ASSERT
-#include "ntqfont.h"
-#include "ntqfontdatabase.h"
-#include "ntqfontmetrics.h"
-#include "ntqfontinfo.h"
-#include "ntqpainter.h"
+#include "tqfont.h"
+#include "tqfontdatabase.h"
+#include "tqfontmetrics.h"
+#include "tqfontinfo.h"
+#include "tqpainter.h"
#include "tqdict.h"
#include "tqcache.h"
#include "tqdatastream.h"
@@ -52,13 +52,13 @@
#include "ntqcleanuphandler.h"
#include "tqstringlist.h"
#ifdef TQ_WS_MAC
-#include "ntqpaintdevicemetrics.h"
+#include "tqpaintdevicemetrics.h"
#endif
#include <private/qunicodetables_p.h>
-#include "qfontdata_p.h"
-#include "qfontengine_p.h"
-#include "qpainter_p.h"
+#include "tqfontdata_p.h"
+#include "tqfontengine_p.h"
+#include "tqpainter_p.h"
#include "tqtextengine_p.h"
// #define TQFONTCACHE_DEBUG
@@ -237,7 +237,7 @@ TQFontEngineData::~TQFontEngineData()
/*!
- \class TQFont ntqfont.h
+ \class TQFont tqfont.h
\brief The TQFont class specifies a font used for drawing text.
\ingroup graphics
@@ -1377,7 +1377,7 @@ void TQFont::setDefaultFont( const TQFont &f )
typedef TQDict<TQStringList> TQFontSubst;
static TQFontSubst *fontSubst = 0;
-static TQSingleCleanupHandler<TQFontSubst> qfont_cleanup_fontsubst;
+static TQSingleCleanupHandler<TQFontSubst> tqfont_cleanup_fontsubst;
// create substitution dict
@@ -1405,7 +1405,7 @@ static void initFontSubst()
fontSubst = new TQFontSubst(17, FALSE);
TQ_CHECK_PTR( fontSubst );
fontSubst->setAutoDelete( TRUE );
- qfont_cleanup_fontsubst.set(&fontSubst);
+ tqfont_cleanup_fontsubst.set(&fontSubst);
for ( int i=0; initTbl[i] != 0; i += 2 )
TQFont::insertSubstitution(TQString::fromLatin1(initTbl[i]),
@@ -1804,7 +1804,7 @@ TQDataStream &operator>>( TQDataStream &s, TQFont &font )
*****************************************************************************/
/*!
- \class TQFontMetrics ntqfontmetrics.h
+ \class TQFontMetrics tqfontmetrics.h
\brief The TQFontMetrics class provides font metrics information.
\ingroup graphics
@@ -2583,7 +2583,7 @@ int TQFontMetrics::lineWidth() const
*****************************************************************************/
/*!
- \class TQFontInfo ntqfontinfo.h
+ \class TQFontInfo tqfontinfo.h
\brief The TQFontInfo class provides general information about fonts.
diff --git a/src/kernel/ntqfont.h b/src/kernel/tqfont.h
index 441b57ddf..43256972b 100644
--- a/src/kernel/ntqfont.h
+++ b/src/kernel/tqfont.h
@@ -194,7 +194,7 @@ public:
static void cacheStatistics();
// a copy of this lives in qunicodetables.cpp, as we can't include
- // ntqfont.h it in tools/. Do not modify without changing the script
+ // tqfont.h it in tools/. Do not modify without changing the script
// enum in qunicodetable_p.h aswell.
enum Script {
// European Alphabetic Scripts
diff --git a/src/kernel/qfont_x11.cpp b/src/kernel/tqfont_x11.cpp
index 9f5cd5744..9acbddd59 100644
--- a/src/kernel/qfont_x11.cpp
+++ b/src/kernel/tqfont_x11.cpp
@@ -44,20 +44,20 @@
#include "qplatformdefs.h"
-#include "ntqfont.h"
+#include "tqfont.h"
#include "ntqapplication.h"
#include "ntqcleanuphandler.h"
-#include "ntqfontinfo.h"
-#include "ntqfontdatabase.h"
-#include "ntqfontmetrics.h"
-#include "ntqpaintdevice.h"
-#include "ntqpaintdevicemetrics.h"
+#include "tqfontinfo.h"
+#include "tqfontdatabase.h"
+#include "tqfontmetrics.h"
+#include "tqpaintdevice.h"
+#include "tqpaintdevicemetrics.h"
#include "tqtextcodec.h"
#include <private/tqfontcodecs_p.h>
#include <private/qunicodetables_p.h>
-#include "qfontdata_p.h"
-#include "qfontengine_p.h"
+#include "tqfontdata_p.h"
+#include "tqfontengine_p.h"
#include "tqtextengine_p.h"
#include "qt_x11_p.h"
@@ -213,7 +213,7 @@ void TQFont::initialize()
#endif // TQT_NO_BIG_CODECS
#endif // TQT_NO_CODECS
- extern int qt_encoding_id_for_mib( int mib ); // from qfontdatabase_x11.cpp
+ extern int qt_encoding_id_for_mib( int mib ); // from tqfontdatabase_x11.cpp
TQTextCodec *codec = TQTextCodec::codecForLocale();
// determine the default encoding id using the locale, otherwise
// fallback to latin1 ( mib == 4 )
@@ -517,7 +517,7 @@ void TQFont::setRawName( const TQString &name )
{
detach();
- // from qfontdatabase_x11.cpp
+ // from tqfontdatabase_x11.cpp
extern bool qt_fillFontDef( const TQCString &xlfd, TQFontDef *fd, int screen );
if ( ! qt_fillFontDef( qt_fixXLFD( name.latin1() ), &d->request, d->screen ) ) {
diff --git a/src/kernel/qfontdata_p.h b/src/kernel/tqfontdata_p.h
index 1aae9b76c..6b42c6bcf 100644
--- a/src/kernel/qfontdata_p.h
+++ b/src/kernel/tqfontdata_p.h
@@ -54,8 +54,8 @@
//
#include "tqobject.h"
-#include "ntqfont.h"
-#include "ntqpaintdevicemetrics.h"
+#include "tqfont.h"
+#include "tqpaintdevicemetrics.h"
// forwards
class TQFontEngine;
diff --git a/src/kernel/qfontdatabase.cpp b/src/kernel/tqfontdatabase.cpp
index 41aa25431..56c1a9ed7 100644
--- a/src/kernel/qfontdatabase.cpp
+++ b/src/kernel/tqfontdatabase.cpp
@@ -38,7 +38,7 @@
**
**********************************************************************/
-#include "ntqfontdatabase.h"
+#include "tqfontdatabase.h"
#ifndef TQT_NO_FONTDATABASE
@@ -46,7 +46,7 @@
#include <ntqapplication.h>
#include <private/qunicodetables_p.h>
-#include "qfontengine_p.h"
+#include "tqfontengine_p.h"
#include <ntqcleanuphandler.h>
@@ -644,16 +644,16 @@ static inline bool canRender( TQFontEngine *fe, TQFont::Script script )
#endif // TQ_WS_X11 || TQ_WS_WIN
-static TQSingleCleanupHandler<TQFontDatabasePrivate> qfontdatabase_cleanup;
+static TQSingleCleanupHandler<TQFontDatabasePrivate> tqfontdatabase_cleanup;
static TQFontDatabasePrivate *db=0;
#define SMOOTH_SCALABLE 0xffff
#if defined( TQ_WS_X11 )
-# include "qfontdatabase_x11.cpp"
+# include "tqfontdatabase_x11.cpp"
#elif defined( TQ_WS_MAC )
-# include "qfontdatabase_mac.cpp"
+# include "tqfontdatabase_mac.cpp"
#elif defined( TQ_WS_WIN )
-# include "qfontdatabase_win.cpp"
+# include "tqfontdatabase_win.cpp"
#endif
static TQtFontStyle *bestStyle(TQtFontFoundry *foundry, const TQtFontStyle::Key &styleKey)
@@ -1291,7 +1291,7 @@ TQString TQFontDatabase::styleString( const TQFont &f )
/*!
- \class TQFontDatabase ntqfontdatabase.h
+ \class TQFontDatabase tqfontdatabase.h
\brief The TQFontDatabase class provides information about the fonts available in the underlying window system.
\ingroup environment
@@ -1331,7 +1331,7 @@ TQString TQFontDatabase::styleString( const TQFont &f )
Example:
\code
#include <ntqapplication.h>
-#include <ntqfontdatabase.h>
+#include <tqfontdatabase.h>
#include <else.h>
int main( int argc, char **argv )
diff --git a/src/kernel/ntqfontdatabase.h b/src/kernel/tqfontdatabase.h
index aa279bfd6..4a5e5c532 100644
--- a/src/kernel/ntqfontdatabase.h
+++ b/src/kernel/tqfontdatabase.h
@@ -45,7 +45,7 @@
#include "ntqwindowdefs.h"
#include "tqstring.h"
#include "tqstringlist.h"
-#include "ntqfont.h"
+#include "tqfont.h"
#include "tqvaluelist.h"
#endif // QT_H
diff --git a/src/kernel/qfontdatabase_x11.cpp b/src/kernel/tqfontdatabase_x11.cpp
index d1045740d..49de442cd 100644
--- a/src/kernel/qfontdatabase_x11.cpp
+++ b/src/kernel/tqfontdatabase_x11.cpp
@@ -41,7 +41,7 @@
#include <qplatformdefs.h>
#include <tqdatetime.h>
-#include <ntqpaintdevicemetrics.h>
+#include <tqpaintdevicemetrics.h>
#include "qt_x11_p.h"
@@ -70,7 +70,7 @@
# define FD_DEBUG if (FALSE) tqDebug
#endif // TQFONTDATABASE_DEBUG
-// from qfont_x11.cpp
+// from tqfont_x11.cpp
extern double qt_pointSize(double pixelSize, TQPaintDevice *paintdevice, int screen);
extern double qt_pixelSize(double pointSize, TQPaintDevice *paintdevice, int screen);
@@ -706,7 +706,7 @@ static TQtFontStyle::Key getStyle( char ** tokens )
}
-extern bool tqt_has_xft; // defined in qfont_x11.cpp
+extern bool tqt_has_xft; // defined in tqfont_x11.cpp
static bool xlfdsFullyLoaded = FALSE;
static unsigned char encodingLoaded[numEncodings];
@@ -1387,7 +1387,7 @@ static void initializeDb()
{
if ( db ) return;
db = new TQFontDatabasePrivate;
- qfontdatabase_cleanup.set(&db);
+ tqfontdatabase_cleanup.set(&db);
#ifndef QT_XFT2
memset( encodingLoaded, FALSE, sizeof( encodingLoaded ) );
diff --git a/src/kernel/qfontengine_p.h b/src/kernel/tqfontengine_p.h
index 3dba677ca..3dba677ca 100644
--- a/src/kernel/qfontengine_p.h
+++ b/src/kernel/tqfontengine_p.h
diff --git a/src/kernel/qfontengine_x11.cpp b/src/kernel/tqfontengine_x11.cpp
index 0a8164d44..6363aac97 100644
--- a/src/kernel/qfontengine_x11.cpp
+++ b/src/kernel/tqfontengine_x11.cpp
@@ -36,7 +36,7 @@
**
**********************************************************************/
-#include "qfontengine_p.h"
+#include "tqfontengine_p.h"
// #define FONTENGINE_DEBUG
@@ -45,22 +45,22 @@
#include <tqtextcodec.h>
#include "tqbitmap.h"
-#include "ntqfontdatabase.h"
-#include "ntqpaintdevice.h"
-#include "ntqpaintdevicemetrics.h"
-#include "ntqpainter.h"
+#include "tqfontdatabase.h"
+#include "tqpaintdevice.h"
+#include "tqpaintdevicemetrics.h"
+#include "tqpainter.h"
#include "tqimage.h"
#include "qt_x11_p.h"
-#include "ntqfont.h"
+#include "tqfont.h"
#include "tqtextengine_p.h"
#include <private/qunicodetables_p.h>
#include <limits.h>
-// defined in qfontdatbase_x11.cpp
+// defined in tqfontdatbase_x11.cpp
extern int qt_mib_for_xlfd_encoding( const char *encoding );
extern int qt_xlfd_encoding_id( const char *encoding );
diff --git a/src/kernel/ntqfontinfo.h b/src/kernel/tqfontinfo.h
index 25c269ff6..c02c01762 100644
--- a/src/kernel/ntqfontinfo.h
+++ b/src/kernel/tqfontinfo.h
@@ -42,7 +42,7 @@
#define TQFONTINFO_H
#ifndef QT_H
-#include "ntqfont.h"
+#include "tqfont.h"
#endif // QT_H
diff --git a/src/kernel/ntqfontmetrics.h b/src/kernel/tqfontmetrics.h
index 887132553..814a411e6 100644
--- a/src/kernel/ntqfontmetrics.h
+++ b/src/kernel/tqfontmetrics.h
@@ -42,7 +42,7 @@
#define TQFONTMETRICS_H
#ifndef QT_H
-#include "ntqfont.h"
+#include "tqfont.h"
#include "ntqrect.h"
#endif // QT_H
diff --git a/src/kernel/tqiconset.cpp b/src/kernel/tqiconset.cpp
index f3e8ac123..a327e554f 100644
--- a/src/kernel/tqiconset.cpp
+++ b/src/kernel/tqiconset.cpp
@@ -46,7 +46,7 @@
#include "tqbitmap.h"
#include "ntqcleanuphandler.h"
#include "tqimage.h"
-#include "ntqpainter.h"
+#include "tqpainter.h"
enum { NumSizes = 2, NumModes = 3, NumStates = 2 };
diff --git a/src/kernel/qmovie.cpp b/src/kernel/tqmovie.cpp
index a26f03d7f..d12ff2f6c 100644
--- a/src/kernel/qmovie.cpp
+++ b/src/kernel/tqmovie.cpp
@@ -41,10 +41,10 @@
// #define QT_SAVE_MOVIE_HACK
#include "tqtimer.h"
-#include "ntqpainter.h"
+#include "tqpainter.h"
#include "tqptrlist.h"
#include "tqbitmap.h"
-#include "ntqmovie.h"
+#include "tqmovie.h"
#include "tqfile.h"
#include "tqbuffer.h"
#include "tqobject.h"
@@ -58,7 +58,7 @@
#include <stdlib.h>
/*!
- \class TQMovie ntqmovie.h
+ \class TQMovie tqmovie.h
\brief The TQMovie class provides incremental loading of animations or images, signalling as it progresses.
\ingroup images
@@ -106,7 +106,7 @@
GIF support may be removed completely in a future version of TQt.
We recommend using the MNG or PNG format.
- \img qmovie.png TQMovie
+ \img tqmovie.png TQMovie
\sa TQLabel::setMovie()
*/
@@ -1040,6 +1040,6 @@ void TQMovie::disconnectStatus(TQObject* receiver, const char *member)
}
-#include "qmovie.moc"
+#include "tqmovie.moc"
#endif // TQT_NO_MOVIE
diff --git a/src/kernel/ntqmovie.h b/src/kernel/tqmovie.h
index 8e92ec6d4..8e92ec6d4 100644
--- a/src/kernel/ntqmovie.h
+++ b/src/kernel/tqmovie.h
diff --git a/src/kernel/ntqpaintdevice.h b/src/kernel/tqpaintdevice.h
index 2b9cd421f..2b9cd421f 100644
--- a/src/kernel/ntqpaintdevice.h
+++ b/src/kernel/tqpaintdevice.h
diff --git a/src/kernel/qpaintdevice_x11.cpp b/src/kernel/tqpaintdevice_x11.cpp
index d40d09ba2..7bfbdf239 100644
--- a/src/kernel/qpaintdevice_x11.cpp
+++ b/src/kernel/tqpaintdevice_x11.cpp
@@ -38,9 +38,9 @@
**
**********************************************************************/
-#include "ntqpaintdevice.h"
-#include "ntqpaintdevicemetrics.h"
-#include "ntqpainter.h"
+#include "tqpaintdevice.h"
+#include "tqpaintdevicemetrics.h"
+#include "tqpainter.h"
#include "tqwidget.h"
#include "tqbitmap.h"
#include "ntqapplication.h"
@@ -48,7 +48,7 @@
/*!
- \class TQPaintDevice ntqpaintdevice.h
+ \class TQPaintDevice tqpaintdevice.h
\brief The TQPaintDevice class is the base class of objects that
can be painted.
@@ -270,7 +270,7 @@ TQPaintDeviceX11Data* TQPaintDevice::getX11Data( bool def ) const
Returns the window system handle of the paint device, for
low-level access. Using this function is not portable.
- The HANDLE type varies with platform; see \c ntqpaintdevice.h and
+ The HANDLE type varies with platform; see \c tqpaintdevice.h and
\c ntqwindowdefs.h for details.
\sa x11Display()
diff --git a/src/kernel/qpaintdevicemetrics.cpp b/src/kernel/tqpaintdevicemetrics.cpp
index 046533fbe..dc456ced3 100644
--- a/src/kernel/qpaintdevicemetrics.cpp
+++ b/src/kernel/tqpaintdevicemetrics.cpp
@@ -38,10 +38,10 @@
**
**********************************************************************/
-#include "ntqpaintdevicemetrics.h"
+#include "tqpaintdevicemetrics.h"
/*!
- \class TQPaintDeviceMetrics ntqpaintdevicemetrics.h
+ \class TQPaintDeviceMetrics tqpaintdevicemetrics.h
\brief The TQPaintDeviceMetrics class provides information about a
paint device.
diff --git a/src/kernel/ntqpaintdevicemetrics.h b/src/kernel/tqpaintdevicemetrics.h
index 1db8ad7df..3d219f41e 100644
--- a/src/kernel/ntqpaintdevicemetrics.h
+++ b/src/kernel/tqpaintdevicemetrics.h
@@ -42,7 +42,7 @@
#define TQPAINTDEVICEMETRICS_H
#ifndef QT_H
-#include "ntqpaintdevice.h"
+#include "tqpaintdevice.h"
#endif // QT_H
diff --git a/src/kernel/qpainter.cpp b/src/kernel/tqpainter.cpp
index a74ca938a..325d11eea 100644
--- a/src/kernel/qpainter.cpp
+++ b/src/kernel/tqpainter.cpp
@@ -38,15 +38,15 @@
**
**********************************************************************/
-#include "ntqpainter.h"
-#include "qpainter_p.h"
+#include "tqpainter.h"
+#include "tqpainter_p.h"
#include "tqbitmap.h"
#include "tqptrstack.h"
#include "tqptrdict.h"
#include "tqdatastream.h"
#include "tqwidget.h"
#include "tqimage.h"
-#include "ntqpaintdevicemetrics.h"
+#include "tqpaintdevicemetrics.h"
#include "ntqapplication.h"
#include "qrichtext_p.h"
#include "tqregexp.h"
@@ -54,7 +54,7 @@
#include <string.h>
#include "tqtextlayout_p.h"
-#include "qfontengine_p.h"
+#include "tqfontengine_p.h"
#ifndef TQT_NO_TRANSFORMATIONS
typedef TQPtrStack<TQWMatrix> TQWMatrixStack;
@@ -66,7 +66,7 @@ typedef TQPtrStack<TQWMatrix> TQWMatrixStack;
#endif
/*!
- \class TQPainter ntqpainter.h
+ \class TQPainter tqpainter.h
\brief The TQPainter class does low-level painting e.g. on widgets.
\ingroup graphics
@@ -2243,7 +2243,7 @@ TQRegion TQPainter::clipRegion( CoordinateMode m ) const
#if !defined(TQ_WS_X11) && !defined(TQ_WS_MAC)
-// The doc and X implementation of this functions is in qpainter_x11.cpp
+// The doc and X implementation of this functions is in tqpainter_x11.cpp
void TQPainter::drawWinFocusRect( int, int, int, int,
bool, const TQColor & )
{
@@ -3512,7 +3512,7 @@ TQDataStream &operator>>( TQDataStream &s, TQPen &p )
*****************************************************************************/
/*!
- \class TQBrush ntqbrush.h
+ \class TQBrush tqbrush.h
\brief The TQBrush class defines the fill pattern of shapes drawn by a TQPainter.
diff --git a/src/kernel/ntqpainter.h b/src/kernel/tqpainter.h
index fb73ada58..bd2799577 100644
--- a/src/kernel/ntqpainter.h
+++ b/src/kernel/tqpainter.h
@@ -43,12 +43,12 @@
#ifndef QT_H
-#include "ntqcolor.h"
-#include "ntqfontmetrics.h"
-#include "ntqfontinfo.h"
+#include "tqcolor.h"
+#include "tqfontmetrics.h"
+#include "tqfontinfo.h"
#include "ntqregion.h"
#include "ntqpen.h"
-#include "ntqbrush.h"
+#include "tqbrush.h"
#include "ntqpointarray.h"
#include "ntqwmatrix.h"
#endif // QT_H
@@ -418,7 +418,7 @@ private: // Disabled copy constructor and operator=
enum TransformationCodes {
TxNone = 0, // transformation codes
- TxTranslate = 1, // copy in qpainter_*.cpp
+ TxTranslate = 1, // copy in tqpainter_*.cpp
TxScale = 2,
TxRotShear = 3
};
diff --git a/src/kernel/qpainter_p.h b/src/kernel/tqpainter_p.h
index 5123a64a4..24edb01e6 100644
--- a/src/kernel/qpainter_p.h
+++ b/src/kernel/tqpainter_p.h
@@ -47,7 +47,7 @@
// -------------
//
// This file is not part of the TQt API. It exists for the convenience
-// of qpainter.cpp and qfont.cpp. This header file may change
+// of tqpainter.cpp and tqfont.cpp. This header file may change
// from version to version without notice, or even be removed.
//
// We mean it.
diff --git a/src/kernel/qpainter_x11.cpp b/src/kernel/tqpainter_x11.cpp
index bfb62de41..e61b2fab2 100644
--- a/src/kernel/qpainter_x11.cpp
+++ b/src/kernel/tqpainter_x11.cpp
@@ -40,19 +40,19 @@
#include "qplatformdefs.h"
-#include "ntqfont.h"
-#include "ntqpainter.h"
+#include "tqfont.h"
+#include "tqpainter.h"
#include "tqwidget.h"
#include "tqbitmap.h"
#include "ntqpixmapcache.h"
#include "tqtextcodec.h"
-#include "ntqpaintdevicemetrics.h"
+#include "tqpaintdevicemetrics.h"
#include "qt_x11_p.h"
#include "tqtextlayout_p.h"
-#include "qfontdata_p.h"
-#include "qfontengine_p.h"
+#include "tqfontdata_p.h"
+#include "tqfontengine_p.h"
#include "tqtextengine_p.h"
#include <math.h>
diff --git a/src/kernel/tqsizegrip.cpp b/src/kernel/tqsizegrip.cpp
index 00c994a3a..18ff03d28 100644
--- a/src/kernel/tqsizegrip.cpp
+++ b/src/kernel/tqsizegrip.cpp
@@ -42,7 +42,7 @@
#ifndef TQT_NO_SIZEGRIP
-#include "ntqpainter.h"
+#include "tqpainter.h"
#include "ntqapplication.h"
#include "tqstyle.h"
diff --git a/src/kernel/tqstyle.cpp b/src/kernel/tqstyle.cpp
index 47755c4ba..a8403969d 100644
--- a/src/kernel/tqstyle.cpp
+++ b/src/kernel/tqstyle.cpp
@@ -41,7 +41,7 @@
#include "tqstyle.h"
#ifndef TQT_NO_STYLE
#include "ntqapplication.h"
-#include "ntqpainter.h"
+#include "tqpainter.h"
#include "tqbitmap.h"
#include "ntqpixmapcache.h"
#include "ntqframe.h"
diff --git a/src/kernel/tqstyle.h b/src/kernel/tqstyle.h
index bd5987d32..15ecd20fe 100644
--- a/src/kernel/tqstyle.h
+++ b/src/kernel/tqstyle.h
@@ -43,7 +43,7 @@
#ifndef QT_H
#include "tqobject.h"
#include "ntqpixmap.h"
-#include "ntqcolor.h"
+#include "tqcolor.h"
#include "tqiconset.h"
#include "ntqtabbar.h"
#include "tqtoolbutton.h"
diff --git a/src/kernel/tqstylesheet.cpp b/src/kernel/tqstylesheet.cpp
index 2af221100..b96ffd963 100644
--- a/src/kernel/tqstylesheet.cpp
+++ b/src/kernel/tqstylesheet.cpp
@@ -44,7 +44,7 @@
#include "private/qrichtext_p.h"
#include "ntqlayout.h"
-#include "ntqpainter.h"
+#include "tqpainter.h"
#include "ntqcleanuphandler.h"
#include <stdio.h>
diff --git a/src/kernel/tqtextengine.cpp b/src/kernel/tqtextengine.cpp
index 9b1ff2e1b..8280340c9 100644
--- a/src/kernel/tqtextengine.cpp
+++ b/src/kernel/tqtextengine.cpp
@@ -39,9 +39,9 @@
#include "tqtextengine_p.h"
#include "qscriptengine_p.h"
-#include <ntqfont.h>
-#include "qfontdata_p.h"
-#include "qfontengine_p.h"
+#include <tqfont.h>
+#include "tqfontdata_p.h"
+#include "tqfontengine_p.h"
#include <tqstring.h>
#include <private/qunicodetables_p.h>
#include <stdlib.h>
diff --git a/src/kernel/tqtextengine_p.h b/src/kernel/tqtextengine_p.h
index 7d641e98e..608bc06de 100644
--- a/src/kernel/tqtextengine_p.h
+++ b/src/kernel/tqtextengine_p.h
@@ -41,7 +41,7 @@
#include "ntqglobal.h"
#include "tqstring.h"
#include "ntqnamespace.h"
-#include <private/qfontdata_p.h>
+#include <private/tqfontdata_p.h>
#endif // QT_H
#include <stdlib.h>
diff --git a/src/kernel/tqtextlayout.cpp b/src/kernel/tqtextlayout.cpp
index 41be6076a..3e71ccd39 100644
--- a/src/kernel/tqtextlayout.cpp
+++ b/src/kernel/tqtextlayout.cpp
@@ -39,9 +39,9 @@
#include "tqtextlayout_p.h"
#include "tqtextengine_p.h"
-#include <ntqfont.h>
+#include <tqfont.h>
#include <ntqapplication.h>
-#include <ntqpainter.h>
+#include <tqpainter.h>
TQRect TQTextItem::rect() const
diff --git a/src/kernel/tqttdeintegration_x11.cpp b/src/kernel/tqttdeintegration_x11.cpp
index c1b99f188..6bd89a390 100644
--- a/src/kernel/tqttdeintegration_x11.cpp
+++ b/src/kernel/tqttdeintegration_x11.cpp
@@ -3,9 +3,9 @@
#include "tqttdeintegration_x11_p.h"
-#include <ntqcolordialog.h>
+#include <tqcolordialog.h>
#include <tqfiledialog.h>
-#include <ntqfontdialog.h>
+#include <tqfontdialog.h>
#include <ntqlibrary.h>
#include <tqregexp.h>
#include <ntqmessagebox.h>
diff --git a/src/kernel/tqwidget.cpp b/src/kernel/tqwidget.cpp
index d5419c8d0..f1f1798d3 100644
--- a/src/kernel/tqwidget.cpp
+++ b/src/kernel/tqwidget.cpp
@@ -49,7 +49,7 @@
#include "ntqpixmap.h"
#include "ntqapplication.h"
#include "qapplication_p.h"
-#include "ntqbrush.h"
+#include "tqbrush.h"
#include "ntqlayout.h"
#include "tqstylefactory.h"
#include "ntqcleanuphandler.h"
@@ -66,7 +66,7 @@
#include "qt_windows.h"
#include "qinputcontext_p.h"
#endif
-#include "qfontdata_p.h"
+#include "tqfontdata_p.h"
/*!
diff --git a/src/kernel/tqwidget.h b/src/kernel/tqwidget.h
index 8d9faf00b..9e1c3a07a 100644
--- a/src/kernel/tqwidget.h
+++ b/src/kernel/tqwidget.h
@@ -44,11 +44,11 @@
#ifndef QT_H
#include "ntqwindowdefs.h"
#include "tqobject.h"
-#include "ntqpaintdevice.h"
+#include "tqpaintdevice.h"
#include "ntqpalette.h"
-#include "ntqfont.h"
-#include "ntqfontmetrics.h"
-#include "ntqfontinfo.h"
+#include "tqfont.h"
+#include "tqfontmetrics.h"
+#include "tqfontinfo.h"
#include "tqsizepolicy.h"
#endif // QT_H
diff --git a/src/kernel/tqwidget_x11.cpp b/src/kernel/tqwidget_x11.cpp
index c3a54d3d8..4e07dd115 100644
--- a/src/kernel/tqwidget_x11.cpp
+++ b/src/kernel/tqwidget_x11.cpp
@@ -41,8 +41,8 @@
#include "ntqapplication.h"
#include "qapplication_p.h"
#include "ntqnamespace.h"
-#include "ntqpaintdevicemetrics.h"
-#include "ntqpainter.h"
+#include "tqpaintdevicemetrics.h"
+#include "tqpainter.h"
#include "tqbitmap.h"
#include "tqimage.h"
#include "tqobjectlist.h"
@@ -95,7 +95,7 @@ extern Atom qt_net_wm_sync_request;
extern bool qt_use_xsync;
#endif
-// defined in qfont_x11.cpp
+// defined in tqfont_x11.cpp
extern bool tqt_has_xft;
int qt_x11_create_desktop_on_screen = -1;
diff --git a/src/kernel/tqimage.cpp b/src/kernel/tqimage.cpp
index e7afa87f1..58b8a1221 100644
--- a/src/kernel/tqimage.cpp
+++ b/src/kernel/tqimage.cpp
@@ -96,7 +96,7 @@
An entry in the color table is an RGB triplet encoded as a \c
uint. Use the \link ::tqRed() tqRed()\endlink, \link ::tqGreen()
tqGreen()\endlink and \link ::tqBlue() tqBlue()\endlink functions (\c
- ntqcolor.h) to access the components, and \link ::tqRgb()
+ tqcolor.h) to access the components, and \link ::tqRgb()
tqRgb\endlink to make an RGB triplet (see the TQColor class
documentation).
@@ -823,7 +823,7 @@ TQImage TQImage::copy(int x, int y, int w, int h, int conversion_flags) const
A color value is an RGB triplet. Use the \link ::tqRed()
tqRed()\endlink, \link ::tqGreen() tqGreen()\endlink and \link
- ::tqBlue() tqBlue()\endlink functions (defined in \c ntqcolor.h) to
+ ::tqBlue() tqBlue()\endlink functions (defined in \c tqcolor.h) to
get the color value components.
\sa setColor() numColors() TQColor
@@ -835,7 +835,7 @@ TQImage TQImage::copy(int x, int y, int w, int h, int conversion_flags) const
Sets a color in the color table at index \a i to \a c.
A color value is an RGB triplet. Use the \link ::tqRgb()
- tqRgb()\endlink function (defined in \c ntqcolor.h) to make RGB
+ tqRgb()\endlink function (defined in \c tqcolor.h) to make RGB
triplets.
\sa color() setNumColors() numColors()
@@ -855,7 +855,7 @@ TQImage TQImage::copy(int x, int y, int w, int h, int conversion_flags) const
directly, because the pixel format depends on the byte order on
the underlying platform. Hint: use \link ::tqRed() tqRed()\endlink,
\link ::tqGreen() tqGreen()\endlink and \link ::tqBlue()
- tqBlue()\endlink, etc. (ntqcolor.h) to access the pixels.
+ tqBlue()\endlink, etc. (tqcolor.h) to access the pixels.
\sa bytesPerLine() bits() jumpTable()
*/
@@ -2297,7 +2297,7 @@ TQImage TQImage::convertBitOrder( Endian bitOrder ) const
return image;
}
// ### Candidate (renamed) for ntqcolor.h
static
bool isGray(TQRgb c)
{
@@ -2297,7 +2297,7 @@ TQImage TQImage::convertBitOrder( Endian bitOrder ) const
return image;
}
-// ### Candidate (renamed) for ntqcolor.h
+// ### Candidate (renamed) for tqcolor.h
static
bool isGray(TQRgb c)